# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/loadtesting/api/v1/agent_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.loadtesting.api.v1.agent import create_compute_instance_pb2 as yandex_dot_cloud_dot_loadtesting_dot_api_dot_v1_dot_agent_dot_create__compute__instance__pb2
from yandex.cloud.loadtesting.api.v1.agent import agent_pb2 as yandex_dot_cloud_dot_loadtesting_dot_api_dot_v1_dot_agent_dot_agent__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/loadtesting/api/v1/agent_service.proto',
  package='yandex.cloud.loadtesting.api.v1',
  syntax='proto3',
  serialized_options=b'\n#yandex.cloud.api.loadtesting.api.v1ZOgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/api/v1;loadtesting',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n3yandex/cloud/loadtesting/api/v1/agent_service.proto\x12\x1fyandex.cloud.loadtesting.api.v1\x1a\x1cgoogle/api/annotations.proto\x1a&yandex/cloud/operation/operation.proto\x1a yandex/cloud/api/operation.proto\x1a\x43yandex/cloud/loadtesting/api/v1/agent/create_compute_instance.proto\x1a\x31yandex/cloud/loadtesting/api/v1/agent/agent.proto\x1a\x1dyandex/cloud/validation.proto\"\xfc\x01\n\x12\x43reateAgentRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x04name\x18\x02 \x01(\tB!\xf2\xc7\x31\x1d|[a-z][-a-z0-9]{1,61}[a-z0-9]\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12]\n\x17\x63ompute_instance_params\x18\x04 \x01(\x0b\x32<.yandex.cloud.loadtesting.api.v1.agent.CreateComputeInstance\x12\x15\n\ragent_version\x18\x05 \x01(\t\"\'\n\x13\x43reateAgentMetadata\x12\x10\n\x08\x61gent_id\x18\x01 \x01(\t\"#\n\x0fGetAgentRequest\x12\x10\n\x08\x61gent_id\x18\x02 \x01(\t\"&\n\x12\x44\x65leteAgentRequest\x12\x10\n\x08\x61gent_id\x18\x01 \x01(\t\"\'\n\x13\x44\x65leteAgentMetadata\x12\x10\n\x08\x61gent_id\x18\x01 \x01(\t2\x94\x04\n\x0c\x41gentService\x12\xac\x01\n\x06\x43reate\x12\x33.yandex.cloud.loadtesting.api.v1.CreateAgentRequest\x1a!.yandex.cloud.operation.Operation\"J\x82\xd3\xe4\x93\x02\x1e\"\x19/loadtesting/api/v1/agent:\x01*\xb2\xd2*\"\n\x13\x43reateAgentMetadata\x12\x0b\x61gent.Agent\x12\x93\x01\n\x03Get\x12\x30.yandex.cloud.loadtesting.api.v1.GetAgentRequest\x1a,.yandex.cloud.loadtesting.api.v1.agent.Agent\",\x82\xd3\xe4\x93\x02&\x12$/loadtesting/api/v1/agent/{agent_id}\x12\xbe\x01\n\x06\x44\x65lete\x12\x33.yandex.cloud.loadtesting.api.v1.DeleteAgentRequest\x1a!.yandex.cloud.operation.Operation\"\\\x82\xd3\xe4\x93\x02&*$/loadtesting/api/v1/agent/{agent_id}\xb2\xd2*,\n\x13\x44\x65leteAgentMetadata\x12\x15google.protobuf.EmptyBv\n#yandex.cloud.api.loadtesting.api.v1ZOgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/api/v1;loadtestingb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,yandex_dot_cloud_dot_operation_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_api_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_loadtesting_dot_api_dot_v1_dot_agent_dot_create__compute__instance__pb2.DESCRIPTOR,yandex_dot_cloud_dot_loadtesting_dot_api_dot_v1_dot_agent_dot_agent__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,])




_CREATEAGENTREQUEST = _descriptor.Descriptor(
  name='CreateAgentRequest',
  full_name='yandex.cloud.loadtesting.api.v1.CreateAgentRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.loadtesting.api.v1.CreateAgentRequest.folder_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.loadtesting.api.v1.CreateAgentRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\3071\035|[a-z][-a-z0-9]{1,61}[a-z0-9]', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.loadtesting.api.v1.CreateAgentRequest.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=256', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='compute_instance_params', full_name='yandex.cloud.loadtesting.api.v1.CreateAgentRequest.compute_instance_params', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='agent_version', full_name='yandex.cloud.loadtesting.api.v1.CreateAgentRequest.agent_version', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=344,
  serialized_end=596,
)


_CREATEAGENTMETADATA = _descriptor.Descriptor(
  name='CreateAgentMetadata',
  full_name='yandex.cloud.loadtesting.api.v1.CreateAgentMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='agent_id', full_name='yandex.cloud.loadtesting.api.v1.CreateAgentMetadata.agent_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=598,
  serialized_end=637,
)


_GETAGENTREQUEST = _descriptor.Descriptor(
  name='GetAgentRequest',
  full_name='yandex.cloud.loadtesting.api.v1.GetAgentRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='agent_id', full_name='yandex.cloud.loadtesting.api.v1.GetAgentRequest.agent_id', index=0,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=639,
  serialized_end=674,
)


_DELETEAGENTREQUEST = _descriptor.Descriptor(
  name='DeleteAgentRequest',
  full_name='yandex.cloud.loadtesting.api.v1.DeleteAgentRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='agent_id', full_name='yandex.cloud.loadtesting.api.v1.DeleteAgentRequest.agent_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=676,
  serialized_end=714,
)


_DELETEAGENTMETADATA = _descriptor.Descriptor(
  name='DeleteAgentMetadata',
  full_name='yandex.cloud.loadtesting.api.v1.DeleteAgentMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='agent_id', full_name='yandex.cloud.loadtesting.api.v1.DeleteAgentMetadata.agent_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=716,
  serialized_end=755,
)

_CREATEAGENTREQUEST.fields_by_name['compute_instance_params'].message_type = yandex_dot_cloud_dot_loadtesting_dot_api_dot_v1_dot_agent_dot_create__compute__instance__pb2._CREATECOMPUTEINSTANCE
DESCRIPTOR.message_types_by_name['CreateAgentRequest'] = _CREATEAGENTREQUEST
DESCRIPTOR.message_types_by_name['CreateAgentMetadata'] = _CREATEAGENTMETADATA
DESCRIPTOR.message_types_by_name['GetAgentRequest'] = _GETAGENTREQUEST
DESCRIPTOR.message_types_by_name['DeleteAgentRequest'] = _DELETEAGENTREQUEST
DESCRIPTOR.message_types_by_name['DeleteAgentMetadata'] = _DELETEAGENTMETADATA
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CreateAgentRequest = _reflection.GeneratedProtocolMessageType('CreateAgentRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEAGENTREQUEST,
  '__module__' : 'yandex.cloud.loadtesting.api.v1.agent_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.loadtesting.api.v1.CreateAgentRequest)
  })
_sym_db.RegisterMessage(CreateAgentRequest)

CreateAgentMetadata = _reflection.GeneratedProtocolMessageType('CreateAgentMetadata', (_message.Message,), {
  'DESCRIPTOR' : _CREATEAGENTMETADATA,
  '__module__' : 'yandex.cloud.loadtesting.api.v1.agent_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.loadtesting.api.v1.CreateAgentMetadata)
  })
_sym_db.RegisterMessage(CreateAgentMetadata)

GetAgentRequest = _reflection.GeneratedProtocolMessageType('GetAgentRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETAGENTREQUEST,
  '__module__' : 'yandex.cloud.loadtesting.api.v1.agent_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.loadtesting.api.v1.GetAgentRequest)
  })
_sym_db.RegisterMessage(GetAgentRequest)

DeleteAgentRequest = _reflection.GeneratedProtocolMessageType('DeleteAgentRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEAGENTREQUEST,
  '__module__' : 'yandex.cloud.loadtesting.api.v1.agent_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.loadtesting.api.v1.DeleteAgentRequest)
  })
_sym_db.RegisterMessage(DeleteAgentRequest)

DeleteAgentMetadata = _reflection.GeneratedProtocolMessageType('DeleteAgentMetadata', (_message.Message,), {
  'DESCRIPTOR' : _DELETEAGENTMETADATA,
  '__module__' : 'yandex.cloud.loadtesting.api.v1.agent_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.loadtesting.api.v1.DeleteAgentMetadata)
  })
_sym_db.RegisterMessage(DeleteAgentMetadata)


DESCRIPTOR._options = None
_CREATEAGENTREQUEST.fields_by_name['folder_id']._options = None
_CREATEAGENTREQUEST.fields_by_name['name']._options = None
_CREATEAGENTREQUEST.fields_by_name['description']._options = None

_AGENTSERVICE = _descriptor.ServiceDescriptor(
  name='AgentService',
  full_name='yandex.cloud.loadtesting.api.v1.AgentService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=758,
  serialized_end=1290,
  methods=[
  _descriptor.MethodDescriptor(
    name='Create',
    full_name='yandex.cloud.loadtesting.api.v1.AgentService.Create',
    index=0,
    containing_service=None,
    input_type=_CREATEAGENTREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002\036\"\031/loadtesting/api/v1/agent:\001*\262\322*\"\n\023CreateAgentMetadata\022\013agent.Agent',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Get',
    full_name='yandex.cloud.loadtesting.api.v1.AgentService.Get',
    index=1,
    containing_service=None,
    input_type=_GETAGENTREQUEST,
    output_type=yandex_dot_cloud_dot_loadtesting_dot_api_dot_v1_dot_agent_dot_agent__pb2._AGENT,
    serialized_options=b'\202\323\344\223\002&\022$/loadtesting/api/v1/agent/{agent_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Delete',
    full_name='yandex.cloud.loadtesting.api.v1.AgentService.Delete',
    index=2,
    containing_service=None,
    input_type=_DELETEAGENTREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002&*$/loadtesting/api/v1/agent/{agent_id}\262\322*,\n\023DeleteAgentMetadata\022\025google.protobuf.Empty',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_AGENTSERVICE)

DESCRIPTOR.services_by_name['AgentService'] = _AGENTSERVICE

# @@protoc_insertion_point(module_scope)
