# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/kms/v1/asymmetricencryption/asymmetric_encryption_key_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.access import access_pb2 as yandex_dot_cloud_dot_access_dot_access__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.kms.v1.asymmetricencryption import asymmetric_encryption_key_pb2 as yandex_dot_cloud_dot_kms_dot_v1_dot_asymmetricencryption_dot_asymmetric__encryption__key__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/kms/v1/asymmetricencryption/asymmetric_encryption_key_service.proto',
  package='yandex.cloud.kms.v1.asymmetricencryption',
  syntax='proto3',
  serialized_options=b'\n\027yandex.cloud.api.kms.v1ZPgithub.com/yandex-cloud/go-genproto/yandex/cloud/kms/v1/asymmetricencryption;kms',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nPyandex/cloud/kms/v1/asymmetricencryption/asymmetric_encryption_key_service.proto\x12(yandex.cloud.kms.v1.asymmetricencryption\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/access/access.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\x1aHyandex/cloud/kms/v1/asymmetricencryption/asymmetric_encryption_key.proto\"\xe2\x03\n$CreateAsymmetricEncryptionKeyRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x17\n\x04name\x18\x02 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1f\n\x0b\x64\x65scription\x18\x03 \x01(\tB\n\x8a\xc8\x31\x06<=1024\x12\xab\x01\n\x06labels\x18\x04 \x03(\x0b\x32Z.yandex.cloud.kms.v1.asymmetricencryption.CreateAsymmetricEncryptionKeyRequest.LabelsEntryB?\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xf2\xc7\x31\x0b[-_0-9a-z]*\xb2\xc8\x31\x06\x1a\x04<=63\xb2\xc8\x31\x12\x12\x10[a-z][-_0-9a-z]*\x12\x65\n\x14\x65ncryption_algorithm\x18\x05 \x01(\x0e\x32G.yandex.cloud.kms.v1.asymmetricencryption.AsymmetricEncryptionAlgorithm\x12\x1b\n\x13\x64\x65letion_protection\x18\x06 \x01(\x08\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"7\n%CreateAsymmetricEncryptionKeyMetadata\x12\x0e\n\x06key_id\x18\x01 \x01(\t\"A\n!GetAsymmetricEncryptionKeyRequest\x12\x1c\n\x06key_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\x84\x01\n#ListAsymmetricEncryptionKeysRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"\x90\x01\n$ListAsymmetricEncryptionKeysResponse\x12O\n\x04keys\x18\x01 \x03(\x0b\x32\x41.yandex.cloud.kms.v1.asymmetricencryption.AsymmetricEncryptionKey\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x89\x04\n$UpdateAsymmetricEncryptionKeyRequest\x12\x1c\n\x06key_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x35\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x04\xe8\xc7\x31\x01\x12\x17\n\x04name\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1f\n\x0b\x64\x65scription\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1024\x12X\n\x06status\x18\x05 \x01(\x0e\x32H.yandex.cloud.kms.v1.asymmetricencryption.AsymmetricEncryptionKey.Status\x12\xab\x01\n\x06labels\x18\x06 \x03(\x0b\x32Z.yandex.cloud.kms.v1.asymmetricencryption.UpdateAsymmetricEncryptionKeyRequest.LabelsEntryB?\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xf2\xc7\x31\x0b[-_0-9a-z]*\xb2\xc8\x31\x06\x1a\x04<=63\xb2\xc8\x31\x12\x12\x10[a-z][-_0-9a-z]*\x12\x1b\n\x13\x64\x65letion_protection\x18\x07 \x01(\x08\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"7\n%UpdateAsymmetricEncryptionKeyMetadata\x12\x0e\n\x06key_id\x18\x01 \x01(\t\"D\n$DeleteAsymmetricEncryptionKeyRequest\x12\x1c\n\x06key_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"7\n%DeleteAsymmetricEncryptionKeyMetadata\x12\x0e\n\x06key_id\x18\x01 \x01(\t\"\x8a\x01\n,ListAsymmetricEncryptionKeyOperationsRequest\x12\x1c\n\x06key_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"\x7f\n-ListAsymmetricEncryptionKeyOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\xd0\x10\n\x1e\x41symmetricEncryptionKeyService\x12\xec\x01\n\x06\x43reate\x12N.yandex.cloud.kms.v1.asymmetricencryption.CreateAsymmetricEncryptionKeyRequest\x1a!.yandex.cloud.operation.Operation\"o\x82\xd3\xe4\x93\x02%\" /kms/v1/asymmetricEncryptionKeys:\x01*\xb2\xd2*@\n%CreateAsymmetricEncryptionKeyMetadata\x12\x17\x41symmetricEncryptionKey\x12\xc8\x01\n\x03Get\x12K.yandex.cloud.kms.v1.asymmetricencryption.GetAsymmetricEncryptionKeyRequest\x1a\x41.yandex.cloud.kms.v1.asymmetricencryption.AsymmetricEncryptionKey\"1\x82\xd3\xe4\x93\x02+\x12)/kms/v1/asymmetricEncryptionKeys/{key_id}\x12\xcf\x01\n\x04List\x12M.yandex.cloud.kms.v1.asymmetricencryption.ListAsymmetricEncryptionKeysRequest\x1aN.yandex.cloud.kms.v1.asymmetricencryption.ListAsymmetricEncryptionKeysResponse\"(\x82\xd3\xe4\x93\x02\"\x12 /kms/v1/asymmetricEncryptionKeys\x12\xf5\x01\n\x06Update\x12N.yandex.cloud.kms.v1.asymmetricencryption.UpdateAsymmetricEncryptionKeyRequest\x1a!.yandex.cloud.operation.Operation\"x\x82\xd3\xe4\x93\x02.2)/kms/v1/asymmetricEncryptionKeys/{key_id}:\x01*\xb2\xd2*@\n%UpdateAsymmetricEncryptionKeyMetadata\x12\x17\x41symmetricEncryptionKey\x12\xf2\x01\n\x06\x44\x65lete\x12N.yandex.cloud.kms.v1.asymmetricencryption.DeleteAsymmetricEncryptionKeyRequest\x1a!.yandex.cloud.operation.Operation\"u\x82\xd3\xe4\x93\x02+*)/kms/v1/asymmetricEncryptionKeys/{key_id}\xb2\xd2*@\n%DeleteAsymmetricEncryptionKeyMetadata\x12\x17\x41symmetricEncryptionKey\x12\xff\x01\n\x0eListOperations\x12V.yandex.cloud.kms.v1.asymmetricencryption.ListAsymmetricEncryptionKeyOperationsRequest\x1aW.yandex.cloud.kms.v1.asymmetricencryption.ListAsymmetricEncryptionKeyOperationsResponse\"<\x82\xd3\xe4\x93\x02\x36\x12\x34/kms/v1/asymmetricEncryptionKeys/{key_id}/operations\x12\xc0\x01\n\x12ListAccessBindings\x12..yandex.cloud.access.ListAccessBindingsRequest\x1a/.yandex.cloud.access.ListAccessBindingsResponse\"I\x82\xd3\xe4\x93\x02\x43\x12\x41/kms/v1/asymmetricEncryptionKeys/{resource_id}:listAccessBindings\x12\xf0\x01\n\x11SetAccessBindings\x12-.yandex.cloud.access.SetAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"\x88\x01\x82\xd3\xe4\x93\x02\x45\"@/kms/v1/asymmetricEncryptionKeys/{resource_id}:setAccessBindings:\x01*\xb2\xd2*9\n access.SetAccessBindingsMetadata\x12\x15google.protobuf.Empty\x12\xfc\x01\n\x14UpdateAccessBindings\x12\x30.yandex.cloud.access.UpdateAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"\x8e\x01\x82\xd3\xe4\x93\x02H\"C/kms/v1/asymmetricEncryptionKeys/{resource_id}:updateAccessBindings:\x01*\xb2\xd2*<\n#access.UpdateAccessBindingsMetadata\x12\x15google.protobuf.EmptyBk\n\x17yandex.cloud.api.kms.v1ZPgithub.com/yandex-cloud/go-genproto/yandex/cloud/kms/v1/asymmetricencryption;kmsb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,yandex_dot_cloud_dot_access_dot_access__pb2.DESCRIPTOR,yandex_dot_cloud_dot_api_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_operation_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_kms_dot_v1_dot_asymmetricencryption_dot_asymmetric__encryption__key__pb2.DESCRIPTOR,])




_CREATEASYMMETRICENCRYPTIONKEYREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yandex.cloud.kms.v1.asymmetricencryption.CreateAsymmetricEncryptionKeyRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.kms.v1.asymmetricencryption.CreateAsymmetricEncryptionKeyRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.kms.v1.asymmetricencryption.CreateAsymmetricEncryptionKeyRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=841,
  serialized_end=886,
)

_CREATEASYMMETRICENCRYPTIONKEYREQUEST = _descriptor.Descriptor(
  name='CreateAsymmetricEncryptionKeyRequest',
  full_name='yandex.cloud.kms.v1.asymmetricencryption.CreateAsymmetricEncryptionKeyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.kms.v1.asymmetricencryption.CreateAsymmetricEncryptionKeyRequest.folder_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.kms.v1.asymmetricencryption.CreateAsymmetricEncryptionKeyRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.kms.v1.asymmetricencryption.CreateAsymmetricEncryptionKeyRequest.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\006<=1024', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yandex.cloud.kms.v1.asymmetricencryption.CreateAsymmetricEncryptionKeyRequest.labels', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\004<=64\212\3101\004<=63\362\3071\013[-_0-9a-z]*\262\3101\006\032\004<=63\262\3101\022\022\020[a-z][-_0-9a-z]*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='encryption_algorithm', full_name='yandex.cloud.kms.v1.asymmetricencryption.CreateAsymmetricEncryptionKeyRequest.encryption_algorithm', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deletion_protection', full_name='yandex.cloud.kms.v1.asymmetricencryption.CreateAsymmetricEncryptionKeyRequest.deletion_protection', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CREATEASYMMETRICENCRYPTIONKEYREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=404,
  serialized_end=886,
)


_CREATEASYMMETRICENCRYPTIONKEYMETADATA = _descriptor.Descriptor(
  name='CreateAsymmetricEncryptionKeyMetadata',
  full_name='yandex.cloud.kms.v1.asymmetricencryption.CreateAsymmetricEncryptionKeyMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key_id', full_name='yandex.cloud.kms.v1.asymmetricencryption.CreateAsymmetricEncryptionKeyMetadata.key_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=888,
  serialized_end=943,
)


_GETASYMMETRICENCRYPTIONKEYREQUEST = _descriptor.Descriptor(
  name='GetAsymmetricEncryptionKeyRequest',
  full_name='yandex.cloud.kms.v1.asymmetricencryption.GetAsymmetricEncryptionKeyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key_id', full_name='yandex.cloud.kms.v1.asymmetricencryption.GetAsymmetricEncryptionKeyRequest.key_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=945,
  serialized_end=1010,
)


_LISTASYMMETRICENCRYPTIONKEYSREQUEST = _descriptor.Descriptor(
  name='ListAsymmetricEncryptionKeysRequest',
  full_name='yandex.cloud.kms.v1.asymmetricencryption.ListAsymmetricEncryptionKeysRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.kms.v1.asymmetricencryption.ListAsymmetricEncryptionKeysRequest.folder_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.kms.v1.asymmetricencryption.ListAsymmetricEncryptionKeysRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.kms.v1.asymmetricencryption.ListAsymmetricEncryptionKeysRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1013,
  serialized_end=1145,
)


_LISTASYMMETRICENCRYPTIONKEYSRESPONSE = _descriptor.Descriptor(
  name='ListAsymmetricEncryptionKeysResponse',
  full_name='yandex.cloud.kms.v1.asymmetricencryption.ListAsymmetricEncryptionKeysResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='keys', full_name='yandex.cloud.kms.v1.asymmetricencryption.ListAsymmetricEncryptionKeysResponse.keys', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.kms.v1.asymmetricencryption.ListAsymmetricEncryptionKeysResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1148,
  serialized_end=1292,
)


_UPDATEASYMMETRICENCRYPTIONKEYREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yandex.cloud.kms.v1.asymmetricencryption.UpdateAsymmetricEncryptionKeyRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.kms.v1.asymmetricencryption.UpdateAsymmetricEncryptionKeyRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.kms.v1.asymmetricencryption.UpdateAsymmetricEncryptionKeyRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=841,
  serialized_end=886,
)

_UPDATEASYMMETRICENCRYPTIONKEYREQUEST = _descriptor.Descriptor(
  name='UpdateAsymmetricEncryptionKeyRequest',
  full_name='yandex.cloud.kms.v1.asymmetricencryption.UpdateAsymmetricEncryptionKeyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key_id', full_name='yandex.cloud.kms.v1.asymmetricencryption.UpdateAsymmetricEncryptionKeyRequest.key_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update_mask', full_name='yandex.cloud.kms.v1.asymmetricencryption.UpdateAsymmetricEncryptionKeyRequest.update_mask', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.kms.v1.asymmetricencryption.UpdateAsymmetricEncryptionKeyRequest.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.kms.v1.asymmetricencryption.UpdateAsymmetricEncryptionKeyRequest.description', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\006<=1024', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='yandex.cloud.kms.v1.asymmetricencryption.UpdateAsymmetricEncryptionKeyRequest.status', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yandex.cloud.kms.v1.asymmetricencryption.UpdateAsymmetricEncryptionKeyRequest.labels', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\004<=64\212\3101\004<=63\362\3071\013[-_0-9a-z]*\262\3101\006\032\004<=63\262\3101\022\022\020[a-z][-_0-9a-z]*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deletion_protection', full_name='yandex.cloud.kms.v1.asymmetricencryption.UpdateAsymmetricEncryptionKeyRequest.deletion_protection', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_UPDATEASYMMETRICENCRYPTIONKEYREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1295,
  serialized_end=1816,
)


_UPDATEASYMMETRICENCRYPTIONKEYMETADATA = _descriptor.Descriptor(
  name='UpdateAsymmetricEncryptionKeyMetadata',
  full_name='yandex.cloud.kms.v1.asymmetricencryption.UpdateAsymmetricEncryptionKeyMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key_id', full_name='yandex.cloud.kms.v1.asymmetricencryption.UpdateAsymmetricEncryptionKeyMetadata.key_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1818,
  serialized_end=1873,
)


_DELETEASYMMETRICENCRYPTIONKEYREQUEST = _descriptor.Descriptor(
  name='DeleteAsymmetricEncryptionKeyRequest',
  full_name='yandex.cloud.kms.v1.asymmetricencryption.DeleteAsymmetricEncryptionKeyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key_id', full_name='yandex.cloud.kms.v1.asymmetricencryption.DeleteAsymmetricEncryptionKeyRequest.key_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1875,
  serialized_end=1943,
)


_DELETEASYMMETRICENCRYPTIONKEYMETADATA = _descriptor.Descriptor(
  name='DeleteAsymmetricEncryptionKeyMetadata',
  full_name='yandex.cloud.kms.v1.asymmetricencryption.DeleteAsymmetricEncryptionKeyMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key_id', full_name='yandex.cloud.kms.v1.asymmetricencryption.DeleteAsymmetricEncryptionKeyMetadata.key_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1945,
  serialized_end=2000,
)


_LISTASYMMETRICENCRYPTIONKEYOPERATIONSREQUEST = _descriptor.Descriptor(
  name='ListAsymmetricEncryptionKeyOperationsRequest',
  full_name='yandex.cloud.kms.v1.asymmetricencryption.ListAsymmetricEncryptionKeyOperationsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key_id', full_name='yandex.cloud.kms.v1.asymmetricencryption.ListAsymmetricEncryptionKeyOperationsRequest.key_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.kms.v1.asymmetricencryption.ListAsymmetricEncryptionKeyOperationsRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.kms.v1.asymmetricencryption.ListAsymmetricEncryptionKeyOperationsRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2003,
  serialized_end=2141,
)


_LISTASYMMETRICENCRYPTIONKEYOPERATIONSRESPONSE = _descriptor.Descriptor(
  name='ListAsymmetricEncryptionKeyOperationsResponse',
  full_name='yandex.cloud.kms.v1.asymmetricencryption.ListAsymmetricEncryptionKeyOperationsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operations', full_name='yandex.cloud.kms.v1.asymmetricencryption.ListAsymmetricEncryptionKeyOperationsResponse.operations', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.kms.v1.asymmetricencryption.ListAsymmetricEncryptionKeyOperationsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2143,
  serialized_end=2270,
)

_CREATEASYMMETRICENCRYPTIONKEYREQUEST_LABELSENTRY.containing_type = _CREATEASYMMETRICENCRYPTIONKEYREQUEST
_CREATEASYMMETRICENCRYPTIONKEYREQUEST.fields_by_name['labels'].message_type = _CREATEASYMMETRICENCRYPTIONKEYREQUEST_LABELSENTRY
_CREATEASYMMETRICENCRYPTIONKEYREQUEST.fields_by_name['encryption_algorithm'].enum_type = yandex_dot_cloud_dot_kms_dot_v1_dot_asymmetricencryption_dot_asymmetric__encryption__key__pb2._ASYMMETRICENCRYPTIONALGORITHM
_LISTASYMMETRICENCRYPTIONKEYSRESPONSE.fields_by_name['keys'].message_type = yandex_dot_cloud_dot_kms_dot_v1_dot_asymmetricencryption_dot_asymmetric__encryption__key__pb2._ASYMMETRICENCRYPTIONKEY
_UPDATEASYMMETRICENCRYPTIONKEYREQUEST_LABELSENTRY.containing_type = _UPDATEASYMMETRICENCRYPTIONKEYREQUEST
_UPDATEASYMMETRICENCRYPTIONKEYREQUEST.fields_by_name['update_mask'].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_UPDATEASYMMETRICENCRYPTIONKEYREQUEST.fields_by_name['status'].enum_type = yandex_dot_cloud_dot_kms_dot_v1_dot_asymmetricencryption_dot_asymmetric__encryption__key__pb2._ASYMMETRICENCRYPTIONKEY_STATUS
_UPDATEASYMMETRICENCRYPTIONKEYREQUEST.fields_by_name['labels'].message_type = _UPDATEASYMMETRICENCRYPTIONKEYREQUEST_LABELSENTRY
_LISTASYMMETRICENCRYPTIONKEYOPERATIONSRESPONSE.fields_by_name['operations'].message_type = yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION
DESCRIPTOR.message_types_by_name['CreateAsymmetricEncryptionKeyRequest'] = _CREATEASYMMETRICENCRYPTIONKEYREQUEST
DESCRIPTOR.message_types_by_name['CreateAsymmetricEncryptionKeyMetadata'] = _CREATEASYMMETRICENCRYPTIONKEYMETADATA
DESCRIPTOR.message_types_by_name['GetAsymmetricEncryptionKeyRequest'] = _GETASYMMETRICENCRYPTIONKEYREQUEST
DESCRIPTOR.message_types_by_name['ListAsymmetricEncryptionKeysRequest'] = _LISTASYMMETRICENCRYPTIONKEYSREQUEST
DESCRIPTOR.message_types_by_name['ListAsymmetricEncryptionKeysResponse'] = _LISTASYMMETRICENCRYPTIONKEYSRESPONSE
DESCRIPTOR.message_types_by_name['UpdateAsymmetricEncryptionKeyRequest'] = _UPDATEASYMMETRICENCRYPTIONKEYREQUEST
DESCRIPTOR.message_types_by_name['UpdateAsymmetricEncryptionKeyMetadata'] = _UPDATEASYMMETRICENCRYPTIONKEYMETADATA
DESCRIPTOR.message_types_by_name['DeleteAsymmetricEncryptionKeyRequest'] = _DELETEASYMMETRICENCRYPTIONKEYREQUEST
DESCRIPTOR.message_types_by_name['DeleteAsymmetricEncryptionKeyMetadata'] = _DELETEASYMMETRICENCRYPTIONKEYMETADATA
DESCRIPTOR.message_types_by_name['ListAsymmetricEncryptionKeyOperationsRequest'] = _LISTASYMMETRICENCRYPTIONKEYOPERATIONSREQUEST
DESCRIPTOR.message_types_by_name['ListAsymmetricEncryptionKeyOperationsResponse'] = _LISTASYMMETRICENCRYPTIONKEYOPERATIONSRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CreateAsymmetricEncryptionKeyRequest = _reflection.GeneratedProtocolMessageType('CreateAsymmetricEncryptionKeyRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _CREATEASYMMETRICENCRYPTIONKEYREQUEST_LABELSENTRY,
    '__module__' : 'yandex.cloud.kms.v1.asymmetricencryption.asymmetric_encryption_key_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.kms.v1.asymmetricencryption.CreateAsymmetricEncryptionKeyRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _CREATEASYMMETRICENCRYPTIONKEYREQUEST,
  '__module__' : 'yandex.cloud.kms.v1.asymmetricencryption.asymmetric_encryption_key_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.kms.v1.asymmetricencryption.CreateAsymmetricEncryptionKeyRequest)
  })
_sym_db.RegisterMessage(CreateAsymmetricEncryptionKeyRequest)
_sym_db.RegisterMessage(CreateAsymmetricEncryptionKeyRequest.LabelsEntry)

CreateAsymmetricEncryptionKeyMetadata = _reflection.GeneratedProtocolMessageType('CreateAsymmetricEncryptionKeyMetadata', (_message.Message,), {
  'DESCRIPTOR' : _CREATEASYMMETRICENCRYPTIONKEYMETADATA,
  '__module__' : 'yandex.cloud.kms.v1.asymmetricencryption.asymmetric_encryption_key_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.kms.v1.asymmetricencryption.CreateAsymmetricEncryptionKeyMetadata)
  })
_sym_db.RegisterMessage(CreateAsymmetricEncryptionKeyMetadata)

GetAsymmetricEncryptionKeyRequest = _reflection.GeneratedProtocolMessageType('GetAsymmetricEncryptionKeyRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETASYMMETRICENCRYPTIONKEYREQUEST,
  '__module__' : 'yandex.cloud.kms.v1.asymmetricencryption.asymmetric_encryption_key_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.kms.v1.asymmetricencryption.GetAsymmetricEncryptionKeyRequest)
  })
_sym_db.RegisterMessage(GetAsymmetricEncryptionKeyRequest)

ListAsymmetricEncryptionKeysRequest = _reflection.GeneratedProtocolMessageType('ListAsymmetricEncryptionKeysRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTASYMMETRICENCRYPTIONKEYSREQUEST,
  '__module__' : 'yandex.cloud.kms.v1.asymmetricencryption.asymmetric_encryption_key_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.kms.v1.asymmetricencryption.ListAsymmetricEncryptionKeysRequest)
  })
_sym_db.RegisterMessage(ListAsymmetricEncryptionKeysRequest)

ListAsymmetricEncryptionKeysResponse = _reflection.GeneratedProtocolMessageType('ListAsymmetricEncryptionKeysResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTASYMMETRICENCRYPTIONKEYSRESPONSE,
  '__module__' : 'yandex.cloud.kms.v1.asymmetricencryption.asymmetric_encryption_key_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.kms.v1.asymmetricencryption.ListAsymmetricEncryptionKeysResponse)
  })
_sym_db.RegisterMessage(ListAsymmetricEncryptionKeysResponse)

UpdateAsymmetricEncryptionKeyRequest = _reflection.GeneratedProtocolMessageType('UpdateAsymmetricEncryptionKeyRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _UPDATEASYMMETRICENCRYPTIONKEYREQUEST_LABELSENTRY,
    '__module__' : 'yandex.cloud.kms.v1.asymmetricencryption.asymmetric_encryption_key_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.kms.v1.asymmetricencryption.UpdateAsymmetricEncryptionKeyRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _UPDATEASYMMETRICENCRYPTIONKEYREQUEST,
  '__module__' : 'yandex.cloud.kms.v1.asymmetricencryption.asymmetric_encryption_key_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.kms.v1.asymmetricencryption.UpdateAsymmetricEncryptionKeyRequest)
  })
_sym_db.RegisterMessage(UpdateAsymmetricEncryptionKeyRequest)
_sym_db.RegisterMessage(UpdateAsymmetricEncryptionKeyRequest.LabelsEntry)

UpdateAsymmetricEncryptionKeyMetadata = _reflection.GeneratedProtocolMessageType('UpdateAsymmetricEncryptionKeyMetadata', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEASYMMETRICENCRYPTIONKEYMETADATA,
  '__module__' : 'yandex.cloud.kms.v1.asymmetricencryption.asymmetric_encryption_key_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.kms.v1.asymmetricencryption.UpdateAsymmetricEncryptionKeyMetadata)
  })
_sym_db.RegisterMessage(UpdateAsymmetricEncryptionKeyMetadata)

DeleteAsymmetricEncryptionKeyRequest = _reflection.GeneratedProtocolMessageType('DeleteAsymmetricEncryptionKeyRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEASYMMETRICENCRYPTIONKEYREQUEST,
  '__module__' : 'yandex.cloud.kms.v1.asymmetricencryption.asymmetric_encryption_key_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.kms.v1.asymmetricencryption.DeleteAsymmetricEncryptionKeyRequest)
  })
_sym_db.RegisterMessage(DeleteAsymmetricEncryptionKeyRequest)

DeleteAsymmetricEncryptionKeyMetadata = _reflection.GeneratedProtocolMessageType('DeleteAsymmetricEncryptionKeyMetadata', (_message.Message,), {
  'DESCRIPTOR' : _DELETEASYMMETRICENCRYPTIONKEYMETADATA,
  '__module__' : 'yandex.cloud.kms.v1.asymmetricencryption.asymmetric_encryption_key_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.kms.v1.asymmetricencryption.DeleteAsymmetricEncryptionKeyMetadata)
  })
_sym_db.RegisterMessage(DeleteAsymmetricEncryptionKeyMetadata)

ListAsymmetricEncryptionKeyOperationsRequest = _reflection.GeneratedProtocolMessageType('ListAsymmetricEncryptionKeyOperationsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTASYMMETRICENCRYPTIONKEYOPERATIONSREQUEST,
  '__module__' : 'yandex.cloud.kms.v1.asymmetricencryption.asymmetric_encryption_key_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.kms.v1.asymmetricencryption.ListAsymmetricEncryptionKeyOperationsRequest)
  })
_sym_db.RegisterMessage(ListAsymmetricEncryptionKeyOperationsRequest)

ListAsymmetricEncryptionKeyOperationsResponse = _reflection.GeneratedProtocolMessageType('ListAsymmetricEncryptionKeyOperationsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTASYMMETRICENCRYPTIONKEYOPERATIONSRESPONSE,
  '__module__' : 'yandex.cloud.kms.v1.asymmetricencryption.asymmetric_encryption_key_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.kms.v1.asymmetricencryption.ListAsymmetricEncryptionKeyOperationsResponse)
  })
_sym_db.RegisterMessage(ListAsymmetricEncryptionKeyOperationsResponse)


DESCRIPTOR._options = None
_CREATEASYMMETRICENCRYPTIONKEYREQUEST_LABELSENTRY._options = None
_CREATEASYMMETRICENCRYPTIONKEYREQUEST.fields_by_name['folder_id']._options = None
_CREATEASYMMETRICENCRYPTIONKEYREQUEST.fields_by_name['name']._options = None
_CREATEASYMMETRICENCRYPTIONKEYREQUEST.fields_by_name['description']._options = None
_CREATEASYMMETRICENCRYPTIONKEYREQUEST.fields_by_name['labels']._options = None
_GETASYMMETRICENCRYPTIONKEYREQUEST.fields_by_name['key_id']._options = None
_LISTASYMMETRICENCRYPTIONKEYSREQUEST.fields_by_name['folder_id']._options = None
_LISTASYMMETRICENCRYPTIONKEYSREQUEST.fields_by_name['page_size']._options = None
_LISTASYMMETRICENCRYPTIONKEYSREQUEST.fields_by_name['page_token']._options = None
_UPDATEASYMMETRICENCRYPTIONKEYREQUEST_LABELSENTRY._options = None
_UPDATEASYMMETRICENCRYPTIONKEYREQUEST.fields_by_name['key_id']._options = None
_UPDATEASYMMETRICENCRYPTIONKEYREQUEST.fields_by_name['update_mask']._options = None
_UPDATEASYMMETRICENCRYPTIONKEYREQUEST.fields_by_name['name']._options = None
_UPDATEASYMMETRICENCRYPTIONKEYREQUEST.fields_by_name['description']._options = None
_UPDATEASYMMETRICENCRYPTIONKEYREQUEST.fields_by_name['labels']._options = None
_DELETEASYMMETRICENCRYPTIONKEYREQUEST.fields_by_name['key_id']._options = None
_LISTASYMMETRICENCRYPTIONKEYOPERATIONSREQUEST.fields_by_name['key_id']._options = None
_LISTASYMMETRICENCRYPTIONKEYOPERATIONSREQUEST.fields_by_name['page_size']._options = None
_LISTASYMMETRICENCRYPTIONKEYOPERATIONSREQUEST.fields_by_name['page_token']._options = None

_ASYMMETRICENCRYPTIONKEYSERVICE = _descriptor.ServiceDescriptor(
  name='AsymmetricEncryptionKeyService',
  full_name='yandex.cloud.kms.v1.asymmetricencryption.AsymmetricEncryptionKeyService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=2273,
  serialized_end=4401,
  methods=[
  _descriptor.MethodDescriptor(
    name='Create',
    full_name='yandex.cloud.kms.v1.asymmetricencryption.AsymmetricEncryptionKeyService.Create',
    index=0,
    containing_service=None,
    input_type=_CREATEASYMMETRICENCRYPTIONKEYREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002%\" /kms/v1/asymmetricEncryptionKeys:\001*\262\322*@\n%CreateAsymmetricEncryptionKeyMetadata\022\027AsymmetricEncryptionKey',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Get',
    full_name='yandex.cloud.kms.v1.asymmetricencryption.AsymmetricEncryptionKeyService.Get',
    index=1,
    containing_service=None,
    input_type=_GETASYMMETRICENCRYPTIONKEYREQUEST,
    output_type=yandex_dot_cloud_dot_kms_dot_v1_dot_asymmetricencryption_dot_asymmetric__encryption__key__pb2._ASYMMETRICENCRYPTIONKEY,
    serialized_options=b'\202\323\344\223\002+\022)/kms/v1/asymmetricEncryptionKeys/{key_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='List',
    full_name='yandex.cloud.kms.v1.asymmetricencryption.AsymmetricEncryptionKeyService.List',
    index=2,
    containing_service=None,
    input_type=_LISTASYMMETRICENCRYPTIONKEYSREQUEST,
    output_type=_LISTASYMMETRICENCRYPTIONKEYSRESPONSE,
    serialized_options=b'\202\323\344\223\002\"\022 /kms/v1/asymmetricEncryptionKeys',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Update',
    full_name='yandex.cloud.kms.v1.asymmetricencryption.AsymmetricEncryptionKeyService.Update',
    index=3,
    containing_service=None,
    input_type=_UPDATEASYMMETRICENCRYPTIONKEYREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002.2)/kms/v1/asymmetricEncryptionKeys/{key_id}:\001*\262\322*@\n%UpdateAsymmetricEncryptionKeyMetadata\022\027AsymmetricEncryptionKey',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Delete',
    full_name='yandex.cloud.kms.v1.asymmetricencryption.AsymmetricEncryptionKeyService.Delete',
    index=4,
    containing_service=None,
    input_type=_DELETEASYMMETRICENCRYPTIONKEYREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002+*)/kms/v1/asymmetricEncryptionKeys/{key_id}\262\322*@\n%DeleteAsymmetricEncryptionKeyMetadata\022\027AsymmetricEncryptionKey',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListOperations',
    full_name='yandex.cloud.kms.v1.asymmetricencryption.AsymmetricEncryptionKeyService.ListOperations',
    index=5,
    containing_service=None,
    input_type=_LISTASYMMETRICENCRYPTIONKEYOPERATIONSREQUEST,
    output_type=_LISTASYMMETRICENCRYPTIONKEYOPERATIONSRESPONSE,
    serialized_options=b'\202\323\344\223\0026\0224/kms/v1/asymmetricEncryptionKeys/{key_id}/operations',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListAccessBindings',
    full_name='yandex.cloud.kms.v1.asymmetricencryption.AsymmetricEncryptionKeyService.ListAccessBindings',
    index=6,
    containing_service=None,
    input_type=yandex_dot_cloud_dot_access_dot_access__pb2._LISTACCESSBINDINGSREQUEST,
    output_type=yandex_dot_cloud_dot_access_dot_access__pb2._LISTACCESSBINDINGSRESPONSE,
    serialized_options=b'\202\323\344\223\002C\022A/kms/v1/asymmetricEncryptionKeys/{resource_id}:listAccessBindings',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetAccessBindings',
    full_name='yandex.cloud.kms.v1.asymmetricencryption.AsymmetricEncryptionKeyService.SetAccessBindings',
    index=7,
    containing_service=None,
    input_type=yandex_dot_cloud_dot_access_dot_access__pb2._SETACCESSBINDINGSREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002E\"@/kms/v1/asymmetricEncryptionKeys/{resource_id}:setAccessBindings:\001*\262\322*9\n access.SetAccessBindingsMetadata\022\025google.protobuf.Empty',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateAccessBindings',
    full_name='yandex.cloud.kms.v1.asymmetricencryption.AsymmetricEncryptionKeyService.UpdateAccessBindings',
    index=8,
    containing_service=None,
    input_type=yandex_dot_cloud_dot_access_dot_access__pb2._UPDATEACCESSBINDINGSREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002H\"C/kms/v1/asymmetricEncryptionKeys/{resource_id}:updateAccessBindings:\001*\262\322*<\n#access.UpdateAccessBindingsMetadata\022\025google.protobuf.Empty',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_ASYMMETRICENCRYPTIONKEYSERVICE)

DESCRIPTOR.services_by_name['AsymmetricEncryptionKeyService'] = _ASYMMETRICENCRYPTIONKEYSERVICE

# @@protoc_insertion_point(module_scope)
