# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/kms/v1/asymmetricsignature/asymmetric_signature_key.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/kms/v1/asymmetricsignature/asymmetric_signature_key.proto',
  package='yandex.cloud.kms.v1.asymmetricsignature',
  syntax='proto3',
  serialized_options=b'\n\027yandex.cloud.api.kms.v1ZOgithub.com/yandex-cloud/go-genproto/yandex/cloud/kms/v1/asymmetricsignature;kms',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nFyandex/cloud/kms/v1/asymmetricsignature/asymmetric_signature_key.proto\x12\'yandex.cloud.kms.v1.asymmetricsignature\x1a\x1fgoogle/protobuf/timestamp.proto\"\xb9\x04\n\x16\x41symmetricSignatureKey\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tfolder_id\x18\x02 \x01(\t\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12[\n\x06labels\x18\x06 \x03(\x0b\x32K.yandex.cloud.kms.v1.asymmetricsignature.AsymmetricSignatureKey.LabelsEntry\x12V\n\x06status\x18\x07 \x01(\x0e\x32\x46.yandex.cloud.kms.v1.asymmetricsignature.AsymmetricSignatureKey.Status\x12\x62\n\x13signature_algorithm\x18\x08 \x01(\x0e\x32\x45.yandex.cloud.kms.v1.asymmetricsignature.AsymmetricSignatureAlgorithm\x12\x1b\n\x13\x64\x65letion_protection\x18\t \x01(\x08\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"H\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\n\n\x06\x41\x43TIVE\x10\x02\x12\x0c\n\x08INACTIVE\x10\x03*\xda\x03\n\x1c\x41symmetricSignatureAlgorithm\x12.\n*ASYMMETRIC_SIGNATURE_ALGORITHM_UNSPECIFIED\x10\x00\x12\x1d\n\x19RSA_2048_SIGN_PSS_SHA_256\x10\x01\x12\x1d\n\x19RSA_2048_SIGN_PSS_SHA_384\x10\x02\x12\x1d\n\x19RSA_2048_SIGN_PSS_SHA_512\x10\x03\x12\x1d\n\x19RSA_3072_SIGN_PSS_SHA_256\x10\x04\x12\x1d\n\x19RSA_3072_SIGN_PSS_SHA_384\x10\x05\x12\x1d\n\x19RSA_3072_SIGN_PSS_SHA_512\x10\x06\x12\x1d\n\x19RSA_4096_SIGN_PSS_SHA_256\x10\x07\x12\x1d\n\x19RSA_4096_SIGN_PSS_SHA_384\x10\x08\x12\x1d\n\x19RSA_4096_SIGN_PSS_SHA_512\x10\t\x12\x1b\n\x17\x45\x43\x44SA_NIST_P256_SHA_256\x10\n\x12\x1b\n\x17\x45\x43\x44SA_NIST_P384_SHA_384\x10\x0b\x12\x1b\n\x17\x45\x43\x44SA_NIST_P521_SHA_512\x10\x0c\x12\x1c\n\x18\x45\x43\x44SA_SECP256_K1_SHA_256\x10\rBj\n\x17yandex.cloud.api.kms.v1ZOgithub.com/yandex-cloud/go-genproto/yandex/cloud/kms/v1/asymmetricsignature;kmsb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])

_ASYMMETRICSIGNATUREALGORITHM = _descriptor.EnumDescriptor(
  name='AsymmetricSignatureAlgorithm',
  full_name='yandex.cloud.kms.v1.asymmetricsignature.AsymmetricSignatureAlgorithm',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ASYMMETRIC_SIGNATURE_ALGORITHM_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RSA_2048_SIGN_PSS_SHA_256', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RSA_2048_SIGN_PSS_SHA_384', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RSA_2048_SIGN_PSS_SHA_512', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RSA_3072_SIGN_PSS_SHA_256', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RSA_3072_SIGN_PSS_SHA_384', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RSA_3072_SIGN_PSS_SHA_512', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RSA_4096_SIGN_PSS_SHA_256', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RSA_4096_SIGN_PSS_SHA_384', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RSA_4096_SIGN_PSS_SHA_512', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ECDSA_NIST_P256_SHA_256', index=10, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ECDSA_NIST_P384_SHA_384', index=11, number=11,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ECDSA_NIST_P521_SHA_512', index=12, number=12,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ECDSA_SECP256_K1_SHA_256', index=13, number=13,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=721,
  serialized_end=1195,
)
_sym_db.RegisterEnumDescriptor(_ASYMMETRICSIGNATUREALGORITHM)

AsymmetricSignatureAlgorithm = enum_type_wrapper.EnumTypeWrapper(_ASYMMETRICSIGNATUREALGORITHM)
ASYMMETRIC_SIGNATURE_ALGORITHM_UNSPECIFIED = 0
RSA_2048_SIGN_PSS_SHA_256 = 1
RSA_2048_SIGN_PSS_SHA_384 = 2
RSA_2048_SIGN_PSS_SHA_512 = 3
RSA_3072_SIGN_PSS_SHA_256 = 4
RSA_3072_SIGN_PSS_SHA_384 = 5
RSA_3072_SIGN_PSS_SHA_512 = 6
RSA_4096_SIGN_PSS_SHA_256 = 7
RSA_4096_SIGN_PSS_SHA_384 = 8
RSA_4096_SIGN_PSS_SHA_512 = 9
ECDSA_NIST_P256_SHA_256 = 10
ECDSA_NIST_P384_SHA_384 = 11
ECDSA_NIST_P521_SHA_512 = 12
ECDSA_SECP256_K1_SHA_256 = 13


_ASYMMETRICSIGNATUREKEY_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='yandex.cloud.kms.v1.asymmetricsignature.AsymmetricSignatureKey.Status',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STATUS_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CREATING', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ACTIVE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INACTIVE', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=646,
  serialized_end=718,
)
_sym_db.RegisterEnumDescriptor(_ASYMMETRICSIGNATUREKEY_STATUS)


_ASYMMETRICSIGNATUREKEY_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yandex.cloud.kms.v1.asymmetricsignature.AsymmetricSignatureKey.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.kms.v1.asymmetricsignature.AsymmetricSignatureKey.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.kms.v1.asymmetricsignature.AsymmetricSignatureKey.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=599,
  serialized_end=644,
)

_ASYMMETRICSIGNATUREKEY = _descriptor.Descriptor(
  name='AsymmetricSignatureKey',
  full_name='yandex.cloud.kms.v1.asymmetricsignature.AsymmetricSignatureKey',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='yandex.cloud.kms.v1.asymmetricsignature.AsymmetricSignatureKey.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.kms.v1.asymmetricsignature.AsymmetricSignatureKey.folder_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='yandex.cloud.kms.v1.asymmetricsignature.AsymmetricSignatureKey.created_at', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.kms.v1.asymmetricsignature.AsymmetricSignatureKey.name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.kms.v1.asymmetricsignature.AsymmetricSignatureKey.description', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yandex.cloud.kms.v1.asymmetricsignature.AsymmetricSignatureKey.labels', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='yandex.cloud.kms.v1.asymmetricsignature.AsymmetricSignatureKey.status', index=6,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signature_algorithm', full_name='yandex.cloud.kms.v1.asymmetricsignature.AsymmetricSignatureKey.signature_algorithm', index=7,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deletion_protection', full_name='yandex.cloud.kms.v1.asymmetricsignature.AsymmetricSignatureKey.deletion_protection', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_ASYMMETRICSIGNATUREKEY_LABELSENTRY, ],
  enum_types=[
    _ASYMMETRICSIGNATUREKEY_STATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=149,
  serialized_end=718,
)

_ASYMMETRICSIGNATUREKEY_LABELSENTRY.containing_type = _ASYMMETRICSIGNATUREKEY
_ASYMMETRICSIGNATUREKEY.fields_by_name['created_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_ASYMMETRICSIGNATUREKEY.fields_by_name['labels'].message_type = _ASYMMETRICSIGNATUREKEY_LABELSENTRY
_ASYMMETRICSIGNATUREKEY.fields_by_name['status'].enum_type = _ASYMMETRICSIGNATUREKEY_STATUS
_ASYMMETRICSIGNATUREKEY.fields_by_name['signature_algorithm'].enum_type = _ASYMMETRICSIGNATUREALGORITHM
_ASYMMETRICSIGNATUREKEY_STATUS.containing_type = _ASYMMETRICSIGNATUREKEY
DESCRIPTOR.message_types_by_name['AsymmetricSignatureKey'] = _ASYMMETRICSIGNATUREKEY
DESCRIPTOR.enum_types_by_name['AsymmetricSignatureAlgorithm'] = _ASYMMETRICSIGNATUREALGORITHM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AsymmetricSignatureKey = _reflection.GeneratedProtocolMessageType('AsymmetricSignatureKey', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _ASYMMETRICSIGNATUREKEY_LABELSENTRY,
    '__module__' : 'yandex.cloud.kms.v1.asymmetricsignature.asymmetric_signature_key_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.kms.v1.asymmetricsignature.AsymmetricSignatureKey.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _ASYMMETRICSIGNATUREKEY,
  '__module__' : 'yandex.cloud.kms.v1.asymmetricsignature.asymmetric_signature_key_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.kms.v1.asymmetricsignature.AsymmetricSignatureKey)
  })
_sym_db.RegisterMessage(AsymmetricSignatureKey)
_sym_db.RegisterMessage(AsymmetricSignatureKey.LabelsEntry)


DESCRIPTOR._options = None
_ASYMMETRICSIGNATUREKEY_LABELSENTRY._options = None
# @@protoc_insertion_point(module_scope)
