# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/marketplace/licensemanager/v1/lock_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.marketplace.licensemanager.v1 import lock_pb2 as yandex_dot_cloud_dot_marketplace_dot_licensemanager_dot_v1_dot_lock__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/marketplace/licensemanager/v1/lock_service.proto',
  package='yandex.cloud.marketplace.licensemanager.v1',
  syntax='proto3',
  serialized_options=b'\n.yandex.cloud.api.marketplace.licensemanager.v1Z]github.com/yandex-cloud/go-genproto/yandex/cloud/marketplace/licensemanager/v1;licensemanager',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n=yandex/cloud/marketplace/licensemanager/v1/lock_service.proto\x12*yandex.cloud.marketplace.licensemanager.v1\x1a\x1cgoogle/api/annotations.proto\x1a yandex/cloud/api/operation.proto\x1a\x35yandex/cloud/marketplace/licensemanager/v1/lock.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"\'\n\x0eGetLockRequest\x12\x15\n\x07lock_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"I\n\x11\x43reateLockRequest\x12\x19\n\x0binstance_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x19\n\x0bresource_id\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\"%\n\x12\x43reateLockMetadata\x12\x0f\n\x07lock_id\x18\x01 \x01(\t\"%\n\x12\x45nsureLockMetadata\x12\x0f\n\x07lock_id\x18\x01 \x01(\t\"*\n\x11\x44\x65leteLockRequest\x12\x15\n\x07lock_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"%\n\x12\x44\x65leteLockMetadata\x12\x0f\n\x07lock_id\x18\x01 \x01(\t\"[\n#GetLockByInstanceAndResourceRequest\x12\x19\n\x0binstance_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x19\n\x0bresource_id\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x32\x88\x08\n\x0bLockService\x12\xac\x01\n\x03Get\x12:.yandex.cloud.marketplace.licensemanager.v1.GetLockRequest\x1a\x30.yandex.cloud.marketplace.licensemanager.v1.Lock\"7\x82\xd3\xe4\x93\x02\x31\x12//marketplace/license-manager/v1/locks/{lock_id}\x12\xe5\x01\n\x18GetByInstanceAndResource\x12O.yandex.cloud.marketplace.licensemanager.v1.GetLockByInstanceAndResourceRequest\x1a\x30.yandex.cloud.marketplace.licensemanager.v1.Lock\"F\x82\xd3\xe4\x93\x02@\x12>/marketplace/license-manager/v1/locks:getByInstanceAndResource\x12\xba\x01\n\x06\x43reate\x12=.yandex.cloud.marketplace.licensemanager.v1.CreateLockRequest\x1a!.yandex.cloud.operation.Operation\"N\x82\xd3\xe4\x93\x02*\"%/marketplace/license-manager/v1/locks:\x01*\xb2\xd2*\x1a\n\x12\x43reateLockMetadata\x12\x04Lock\x12\xcf\x01\n\x06\x45nsure\x12=.yandex.cloud.marketplace.licensemanager.v1.CreateLockRequest\x1a!.yandex.cloud.operation.Operation\"c\x82\xd3\xe4\x93\x02?\":/marketplace/license-manager/v1/locks/{instance_id}:ensure:\x01*\xb2\xd2*\x1a\n\x12\x43reateLockMetadata\x12\x04Lock\x12\xd2\x01\n\x06\x44\x65lete\x12=.yandex.cloud.marketplace.licensemanager.v1.DeleteLockRequest\x1a!.yandex.cloud.operation.Operation\"f\x82\xd3\xe4\x93\x02\x31*//marketplace/license-manager/v1/locks/{lock_id}\xb2\xd2*+\n\x12\x44\x65leteLockMetadata\x12\x15google.protobuf.EmptyB\x8f\x01\n.yandex.cloud.api.marketplace.licensemanager.v1Z]github.com/yandex-cloud/go-genproto/yandex/cloud/marketplace/licensemanager/v1;licensemanagerb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,yandex_dot_cloud_dot_api_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_marketplace_dot_licensemanager_dot_v1_dot_lock__pb2.DESCRIPTOR,yandex_dot_cloud_dot_operation_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,])




_GETLOCKREQUEST = _descriptor.Descriptor(
  name='GetLockRequest',
  full_name='yandex.cloud.marketplace.licensemanager.v1.GetLockRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='lock_id', full_name='yandex.cloud.marketplace.licensemanager.v1.GetLockRequest.lock_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=299,
  serialized_end=338,
)


_CREATELOCKREQUEST = _descriptor.Descriptor(
  name='CreateLockRequest',
  full_name='yandex.cloud.marketplace.licensemanager.v1.CreateLockRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance_id', full_name='yandex.cloud.marketplace.licensemanager.v1.CreateLockRequest.instance_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resource_id', full_name='yandex.cloud.marketplace.licensemanager.v1.CreateLockRequest.resource_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=340,
  serialized_end=413,
)


_CREATELOCKMETADATA = _descriptor.Descriptor(
  name='CreateLockMetadata',
  full_name='yandex.cloud.marketplace.licensemanager.v1.CreateLockMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='lock_id', full_name='yandex.cloud.marketplace.licensemanager.v1.CreateLockMetadata.lock_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=415,
  serialized_end=452,
)


_ENSURELOCKMETADATA = _descriptor.Descriptor(
  name='EnsureLockMetadata',
  full_name='yandex.cloud.marketplace.licensemanager.v1.EnsureLockMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='lock_id', full_name='yandex.cloud.marketplace.licensemanager.v1.EnsureLockMetadata.lock_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=454,
  serialized_end=491,
)


_DELETELOCKREQUEST = _descriptor.Descriptor(
  name='DeleteLockRequest',
  full_name='yandex.cloud.marketplace.licensemanager.v1.DeleteLockRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='lock_id', full_name='yandex.cloud.marketplace.licensemanager.v1.DeleteLockRequest.lock_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=493,
  serialized_end=535,
)


_DELETELOCKMETADATA = _descriptor.Descriptor(
  name='DeleteLockMetadata',
  full_name='yandex.cloud.marketplace.licensemanager.v1.DeleteLockMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='lock_id', full_name='yandex.cloud.marketplace.licensemanager.v1.DeleteLockMetadata.lock_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=537,
  serialized_end=574,
)


_GETLOCKBYINSTANCEANDRESOURCEREQUEST = _descriptor.Descriptor(
  name='GetLockByInstanceAndResourceRequest',
  full_name='yandex.cloud.marketplace.licensemanager.v1.GetLockByInstanceAndResourceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance_id', full_name='yandex.cloud.marketplace.licensemanager.v1.GetLockByInstanceAndResourceRequest.instance_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resource_id', full_name='yandex.cloud.marketplace.licensemanager.v1.GetLockByInstanceAndResourceRequest.resource_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=576,
  serialized_end=667,
)

DESCRIPTOR.message_types_by_name['GetLockRequest'] = _GETLOCKREQUEST
DESCRIPTOR.message_types_by_name['CreateLockRequest'] = _CREATELOCKREQUEST
DESCRIPTOR.message_types_by_name['CreateLockMetadata'] = _CREATELOCKMETADATA
DESCRIPTOR.message_types_by_name['EnsureLockMetadata'] = _ENSURELOCKMETADATA
DESCRIPTOR.message_types_by_name['DeleteLockRequest'] = _DELETELOCKREQUEST
DESCRIPTOR.message_types_by_name['DeleteLockMetadata'] = _DELETELOCKMETADATA
DESCRIPTOR.message_types_by_name['GetLockByInstanceAndResourceRequest'] = _GETLOCKBYINSTANCEANDRESOURCEREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetLockRequest = _reflection.GeneratedProtocolMessageType('GetLockRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETLOCKREQUEST,
  '__module__' : 'yandex.cloud.marketplace.licensemanager.v1.lock_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.marketplace.licensemanager.v1.GetLockRequest)
  })
_sym_db.RegisterMessage(GetLockRequest)

CreateLockRequest = _reflection.GeneratedProtocolMessageType('CreateLockRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATELOCKREQUEST,
  '__module__' : 'yandex.cloud.marketplace.licensemanager.v1.lock_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.marketplace.licensemanager.v1.CreateLockRequest)
  })
_sym_db.RegisterMessage(CreateLockRequest)

CreateLockMetadata = _reflection.GeneratedProtocolMessageType('CreateLockMetadata', (_message.Message,), {
  'DESCRIPTOR' : _CREATELOCKMETADATA,
  '__module__' : 'yandex.cloud.marketplace.licensemanager.v1.lock_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.marketplace.licensemanager.v1.CreateLockMetadata)
  })
_sym_db.RegisterMessage(CreateLockMetadata)

EnsureLockMetadata = _reflection.GeneratedProtocolMessageType('EnsureLockMetadata', (_message.Message,), {
  'DESCRIPTOR' : _ENSURELOCKMETADATA,
  '__module__' : 'yandex.cloud.marketplace.licensemanager.v1.lock_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.marketplace.licensemanager.v1.EnsureLockMetadata)
  })
_sym_db.RegisterMessage(EnsureLockMetadata)

DeleteLockRequest = _reflection.GeneratedProtocolMessageType('DeleteLockRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETELOCKREQUEST,
  '__module__' : 'yandex.cloud.marketplace.licensemanager.v1.lock_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.marketplace.licensemanager.v1.DeleteLockRequest)
  })
_sym_db.RegisterMessage(DeleteLockRequest)

DeleteLockMetadata = _reflection.GeneratedProtocolMessageType('DeleteLockMetadata', (_message.Message,), {
  'DESCRIPTOR' : _DELETELOCKMETADATA,
  '__module__' : 'yandex.cloud.marketplace.licensemanager.v1.lock_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.marketplace.licensemanager.v1.DeleteLockMetadata)
  })
_sym_db.RegisterMessage(DeleteLockMetadata)

GetLockByInstanceAndResourceRequest = _reflection.GeneratedProtocolMessageType('GetLockByInstanceAndResourceRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETLOCKBYINSTANCEANDRESOURCEREQUEST,
  '__module__' : 'yandex.cloud.marketplace.licensemanager.v1.lock_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.marketplace.licensemanager.v1.GetLockByInstanceAndResourceRequest)
  })
_sym_db.RegisterMessage(GetLockByInstanceAndResourceRequest)


DESCRIPTOR._options = None
_GETLOCKREQUEST.fields_by_name['lock_id']._options = None
_CREATELOCKREQUEST.fields_by_name['instance_id']._options = None
_CREATELOCKREQUEST.fields_by_name['resource_id']._options = None
_DELETELOCKREQUEST.fields_by_name['lock_id']._options = None
_GETLOCKBYINSTANCEANDRESOURCEREQUEST.fields_by_name['instance_id']._options = None
_GETLOCKBYINSTANCEANDRESOURCEREQUEST.fields_by_name['resource_id']._options = None

_LOCKSERVICE = _descriptor.ServiceDescriptor(
  name='LockService',
  full_name='yandex.cloud.marketplace.licensemanager.v1.LockService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=670,
  serialized_end=1702,
  methods=[
  _descriptor.MethodDescriptor(
    name='Get',
    full_name='yandex.cloud.marketplace.licensemanager.v1.LockService.Get',
    index=0,
    containing_service=None,
    input_type=_GETLOCKREQUEST,
    output_type=yandex_dot_cloud_dot_marketplace_dot_licensemanager_dot_v1_dot_lock__pb2._LOCK,
    serialized_options=b'\202\323\344\223\0021\022//marketplace/license-manager/v1/locks/{lock_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetByInstanceAndResource',
    full_name='yandex.cloud.marketplace.licensemanager.v1.LockService.GetByInstanceAndResource',
    index=1,
    containing_service=None,
    input_type=_GETLOCKBYINSTANCEANDRESOURCEREQUEST,
    output_type=yandex_dot_cloud_dot_marketplace_dot_licensemanager_dot_v1_dot_lock__pb2._LOCK,
    serialized_options=b'\202\323\344\223\002@\022>/marketplace/license-manager/v1/locks:getByInstanceAndResource',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Create',
    full_name='yandex.cloud.marketplace.licensemanager.v1.LockService.Create',
    index=2,
    containing_service=None,
    input_type=_CREATELOCKREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002*\"%/marketplace/license-manager/v1/locks:\001*\262\322*\032\n\022CreateLockMetadata\022\004Lock',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Ensure',
    full_name='yandex.cloud.marketplace.licensemanager.v1.LockService.Ensure',
    index=3,
    containing_service=None,
    input_type=_CREATELOCKREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002?\":/marketplace/license-manager/v1/locks/{instance_id}:ensure:\001*\262\322*\032\n\022CreateLockMetadata\022\004Lock',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Delete',
    full_name='yandex.cloud.marketplace.licensemanager.v1.LockService.Delete',
    index=4,
    containing_service=None,
    input_type=_DELETELOCKREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\0021*//marketplace/license-manager/v1/locks/{lock_id}\262\322*+\n\022DeleteLockMetadata\022\025google.protobuf.Empty',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_LOCKSERVICE)

DESCRIPTOR.services_by_name['LockService'] = _LOCKSERVICE

# @@protoc_insertion_point(module_scope)
