# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/kms/v1/asymmetricencryption/asymmetric_encryption_crypto_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/kms/v1/asymmetricencryption/asymmetric_encryption_crypto_service.proto',
  package='yandex.cloud.kms.v1.asymmetricencryption',
  syntax='proto3',
  serialized_options=b'\n\027yandex.cloud.api.kms.v1ZPgithub.com/yandex-cloud/go-genproto/yandex/cloud/kms/v1/asymmetricencryption;kms',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nSyandex/cloud/kms/v1/asymmetricencryption/asymmetric_encryption_crypto_service.proto\x12(yandex.cloud.kms.v1.asymmetricencryption\x1a\x1cgoogle/api/annotations.proto\x1a\x1dyandex/cloud/validation.proto\"]\n\x18\x41symmetricDecryptRequest\x12\x1c\n\x06key_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12#\n\nciphertext\x18\x02 \x01(\x0c\x42\x0f\xe8\xc7\x31\x01\x8a\xc8\x31\x07<=32768\">\n\x19\x41symmetricDecryptResponse\x12\x0e\n\x06key_id\x18\x01 \x01(\t\x12\x11\n\tplaintext\x18\x02 \x01(\x0c\"=\n\x1d\x41symmetricGetPublicKeyRequest\x12\x1c\n\x06key_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"D\n\x1e\x41symmetricGetPublicKeyResponse\x12\x0e\n\x06key_id\x18\x01 \x01(\t\x12\x12\n\npublic_key\x18\x02 \x01(\t2\xd7\x03\n!AsymmetricEncryptionCryptoService\x12\xd0\x01\n\x07\x44\x65\x63rypt\x12\x42.yandex.cloud.kms.v1.asymmetricencryption.AsymmetricDecryptRequest\x1a\x43.yandex.cloud.kms.v1.asymmetricencryption.AsymmetricDecryptResponse\"<\x82\xd3\xe4\x93\x02\x36\"1/kms/v1/asymmetricEncryptionKeys/{key_id}:decrypt:\x01*\x12\xde\x01\n\x0cGetPublicKey\x12G.yandex.cloud.kms.v1.asymmetricencryption.AsymmetricGetPublicKeyRequest\x1aH.yandex.cloud.kms.v1.asymmetricencryption.AsymmetricGetPublicKeyResponse\";\x82\xd3\xe4\x93\x02\x35\x12\x33/kms/v1/asymmetricEncryptionKeys/{key_id}/publicKeyBk\n\x17yandex.cloud.api.kms.v1ZPgithub.com/yandex-cloud/go-genproto/yandex/cloud/kms/v1/asymmetricencryption;kmsb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,])




_ASYMMETRICDECRYPTREQUEST = _descriptor.Descriptor(
  name='AsymmetricDecryptRequest',
  full_name='yandex.cloud.kms.v1.asymmetricencryption.AsymmetricDecryptRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key_id', full_name='yandex.cloud.kms.v1.asymmetricencryption.AsymmetricDecryptRequest.key_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ciphertext', full_name='yandex.cloud.kms.v1.asymmetricencryption.AsymmetricDecryptRequest.ciphertext', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\007<=32768', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=190,
  serialized_end=283,
)


_ASYMMETRICDECRYPTRESPONSE = _descriptor.Descriptor(
  name='AsymmetricDecryptResponse',
  full_name='yandex.cloud.kms.v1.asymmetricencryption.AsymmetricDecryptResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key_id', full_name='yandex.cloud.kms.v1.asymmetricencryption.AsymmetricDecryptResponse.key_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='plaintext', full_name='yandex.cloud.kms.v1.asymmetricencryption.AsymmetricDecryptResponse.plaintext', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=285,
  serialized_end=347,
)


_ASYMMETRICGETPUBLICKEYREQUEST = _descriptor.Descriptor(
  name='AsymmetricGetPublicKeyRequest',
  full_name='yandex.cloud.kms.v1.asymmetricencryption.AsymmetricGetPublicKeyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key_id', full_name='yandex.cloud.kms.v1.asymmetricencryption.AsymmetricGetPublicKeyRequest.key_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=349,
  serialized_end=410,
)


_ASYMMETRICGETPUBLICKEYRESPONSE = _descriptor.Descriptor(
  name='AsymmetricGetPublicKeyResponse',
  full_name='yandex.cloud.kms.v1.asymmetricencryption.AsymmetricGetPublicKeyResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key_id', full_name='yandex.cloud.kms.v1.asymmetricencryption.AsymmetricGetPublicKeyResponse.key_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='public_key', full_name='yandex.cloud.kms.v1.asymmetricencryption.AsymmetricGetPublicKeyResponse.public_key', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=412,
  serialized_end=480,
)

DESCRIPTOR.message_types_by_name['AsymmetricDecryptRequest'] = _ASYMMETRICDECRYPTREQUEST
DESCRIPTOR.message_types_by_name['AsymmetricDecryptResponse'] = _ASYMMETRICDECRYPTRESPONSE
DESCRIPTOR.message_types_by_name['AsymmetricGetPublicKeyRequest'] = _ASYMMETRICGETPUBLICKEYREQUEST
DESCRIPTOR.message_types_by_name['AsymmetricGetPublicKeyResponse'] = _ASYMMETRICGETPUBLICKEYRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AsymmetricDecryptRequest = _reflection.GeneratedProtocolMessageType('AsymmetricDecryptRequest', (_message.Message,), {
  'DESCRIPTOR' : _ASYMMETRICDECRYPTREQUEST,
  '__module__' : 'yandex.cloud.kms.v1.asymmetricencryption.asymmetric_encryption_crypto_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.kms.v1.asymmetricencryption.AsymmetricDecryptRequest)
  })
_sym_db.RegisterMessage(AsymmetricDecryptRequest)

AsymmetricDecryptResponse = _reflection.GeneratedProtocolMessageType('AsymmetricDecryptResponse', (_message.Message,), {
  'DESCRIPTOR' : _ASYMMETRICDECRYPTRESPONSE,
  '__module__' : 'yandex.cloud.kms.v1.asymmetricencryption.asymmetric_encryption_crypto_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.kms.v1.asymmetricencryption.AsymmetricDecryptResponse)
  })
_sym_db.RegisterMessage(AsymmetricDecryptResponse)

AsymmetricGetPublicKeyRequest = _reflection.GeneratedProtocolMessageType('AsymmetricGetPublicKeyRequest', (_message.Message,), {
  'DESCRIPTOR' : _ASYMMETRICGETPUBLICKEYREQUEST,
  '__module__' : 'yandex.cloud.kms.v1.asymmetricencryption.asymmetric_encryption_crypto_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.kms.v1.asymmetricencryption.AsymmetricGetPublicKeyRequest)
  })
_sym_db.RegisterMessage(AsymmetricGetPublicKeyRequest)

AsymmetricGetPublicKeyResponse = _reflection.GeneratedProtocolMessageType('AsymmetricGetPublicKeyResponse', (_message.Message,), {
  'DESCRIPTOR' : _ASYMMETRICGETPUBLICKEYRESPONSE,
  '__module__' : 'yandex.cloud.kms.v1.asymmetricencryption.asymmetric_encryption_crypto_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.kms.v1.asymmetricencryption.AsymmetricGetPublicKeyResponse)
  })
_sym_db.RegisterMessage(AsymmetricGetPublicKeyResponse)


DESCRIPTOR._options = None
_ASYMMETRICDECRYPTREQUEST.fields_by_name['key_id']._options = None
_ASYMMETRICDECRYPTREQUEST.fields_by_name['ciphertext']._options = None
_ASYMMETRICGETPUBLICKEYREQUEST.fields_by_name['key_id']._options = None

_ASYMMETRICENCRYPTIONCRYPTOSERVICE = _descriptor.ServiceDescriptor(
  name='AsymmetricEncryptionCryptoService',
  full_name='yandex.cloud.kms.v1.asymmetricencryption.AsymmetricEncryptionCryptoService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=483,
  serialized_end=954,
  methods=[
  _descriptor.MethodDescriptor(
    name='Decrypt',
    full_name='yandex.cloud.kms.v1.asymmetricencryption.AsymmetricEncryptionCryptoService.Decrypt',
    index=0,
    containing_service=None,
    input_type=_ASYMMETRICDECRYPTREQUEST,
    output_type=_ASYMMETRICDECRYPTRESPONSE,
    serialized_options=b'\202\323\344\223\0026\"1/kms/v1/asymmetricEncryptionKeys/{key_id}:decrypt:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetPublicKey',
    full_name='yandex.cloud.kms.v1.asymmetricencryption.AsymmetricEncryptionCryptoService.GetPublicKey',
    index=1,
    containing_service=None,
    input_type=_ASYMMETRICGETPUBLICKEYREQUEST,
    output_type=_ASYMMETRICGETPUBLICKEYRESPONSE,
    serialized_options=b'\202\323\344\223\0025\0223/kms/v1/asymmetricEncryptionKeys/{key_id}/publicKey',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_ASYMMETRICENCRYPTIONCRYPTOSERVICE)

DESCRIPTOR.services_by_name['AsymmetricEncryptionCryptoService'] = _ASYMMETRICENCRYPTIONCRYPTOSERVICE

# @@protoc_insertion_point(module_scope)
